@@ -1,17 +1,26 @@
-use std::ops::Deref;
+use std::{ops::Deref, str::FromStr};
+
+use anyhow::{anyhow, Result};
+use itertools::Itertools;
 
 use super::Block;
 
 #[derive(Clone, Copy, Debug)]
-pub enum BlockSize {
+pub(crate) enum BlockSize {
     Eight,
     Sixteen,
 }
 
-pub trait BlockSizeTrait {
+pub(crate) trait BlockSizeTrait {
     fn block_size(&self) -> BlockSize;
 }
 
+impl BlockSize {
+    fn variants() -> &'static [Self] {
+        &[BlockSize::Eight, BlockSize::Sixteen]
+    }
+}
+
 impl From<u8> for BlockSize {
     fn from(data: u8) -> Self {
         match data {
@@ -32,12 +41,21 @@ impl From<usize> for BlockSize {
     }
 }
 
-impl From<&str> for BlockSize {
-    fn from(data: &str) -> Self {
+impl FromStr for BlockSize {
+    type Err = anyhow::Error;
+
+    fn from_str(data: &str) -> Result<Self> {
         match data {
-            "8" => Self::Eight,
-            "16" => Self::Sixteen,
-            _ => unreachable!(format!("Invalid block size: {}", data)),
+            "8" => Ok(Self::Eight),
+            "16" => Ok(Self::Sixteen),
+            _ => Err(anyhow!(
+                "`{}` is an invalid block size. Expected one of: [{}]",
+                data,
+                Self::variants()
+                    .iter()
+                    .map(|variant| variant.to_string())
+                    .join(", ")
+            )),
         }
     }
 }
