@@ -1,8 +1,8 @@
-pub mod calibration_response;
+pub(super) mod calibration_response;
 
 use calibration_response::CalibrationResponse;
 
-use std::{collections::HashMap, thread, time::Duration};
+use std::{collections::HashMap, thread};
 
 use anyhow::{anyhow, Context, Result};
 use log::{debug, info, warn};
@@ -17,7 +17,7 @@ use crate::{
     other::{RETRY_DELAY_MS, RETRY_MAX_ATTEMPTS},
 };
 
-pub struct Calibrator<'a> {
+pub(super) struct Calibrator<'a> {
     forged_cypher_text: ForgedCypherText<'a>,
 }
 
@@ -123,7 +123,7 @@ fn calibrate_while_handling_retries(
         ));
     }
 
-    thread::sleep(Duration::from_millis(oracle.thread_delay()));
+    thread::sleep(**oracle.thread_delay());
 
     match oracle.ask_validation(forged_cypher_text) {
         Ok(correct_padding) => OperationResult::Ok(correct_padding),
