@@ -2,16 +2,16 @@ use std::str::FromStr;
 
 use anyhow::{anyhow, Result};
 
-use crate::block::Block;
+use crate::{block::Block, config::encoding_option::EncodingOption};
 
 #[derive(Debug, Clone, Copy)]
-pub enum Encoding {
+pub(crate) enum Encoding {
     Hex,
     Base64,
     Base64Url,
 }
 
-pub trait Encode<'a> {
+pub(crate) trait Encode<'a> {
     type Blocks: IntoIterator<Item = &'a Block>;
 
     fn encode(&'a self) -> String;
@@ -21,7 +21,7 @@ pub trait Encode<'a> {
     fn used_encoding(&self) -> &Encoding;
 }
 
-pub trait AmountBlocksTrait {
+pub(crate) trait AmountBlocksTrait {
     fn amount_blocks(&self) -> usize;
 }
 
@@ -40,3 +40,18 @@ impl FromStr for Encoding {
         }
     }
 }
+
+impl TryFrom<&EncodingOption> for Encoding {
+    type Error = anyhow::Error;
+
+    fn try_from(encoding: &EncodingOption) -> Result<Self> {
+        match encoding {
+            EncodingOption::Hex => Ok(Self::Hex),
+            EncodingOption::Base64 => Ok(Self::Base64),
+            EncodingOption::Base64Url => Ok(Self::Base64Url),
+            EncodingOption::Auto => Err(anyhow!(
+                "`EncodingOption::Auto` cannot be converted into a specific `Encoding`"
+            )),
+        }
+    }
+}
