@@ -3,7 +3,7 @@ use std::path::Path;
 use anyhow::{anyhow, Context, Result};
 use log::LevelFilter;
 
-pub const LOG_TARGET: &str = "rustpad";
+pub(super) const LOG_TARGET: &str = "rustpad";
 
 pub(super) fn init_logging(log_level: LevelFilter, output_file: Option<&Path>) -> Result<()> {
     tui_logger::init_logger(log_level)
