@@ -1,14 +1,17 @@
+pub(super) mod oracle_location;
+pub(super) mod script;
+pub(super) mod web;
+
 use anyhow::Result;
 
-use crate::{config::SubConfig, cypher_text::encode::Encode};
+use crate::{
+    config::{thread_delay::ThreadDelay, SubConfig},
+    cypher_text::encode::Encode,
+};
 
 use self::oracle_location::OracleLocation;
 
-pub mod oracle_location;
-pub mod script;
-pub mod web;
-
-pub trait Oracle: Sync {
+pub(super) trait Oracle: Sync {
     /// Constructor
     fn visit(oracle_location: &OracleLocation, oracle_config: &SubConfig) -> Result<Self>
     where
@@ -18,5 +21,5 @@ pub trait Oracle: Sync {
     fn ask_validation<'a>(&self, cypher_text: &'a impl Encode<'a>) -> Result<bool>;
 
     fn location(&self) -> OracleLocation;
-    fn thread_delay(&self) -> u64;
+    fn thread_delay(&self) -> &ThreadDelay;
 }
