@@ -6,13 +6,13 @@ use std::{
 use anyhow::{anyhow, Context, Result};
 
 use crate::{
-    config::{script_config::ScriptConfig, SubConfig},
+    config::{thread_delay::ThreadDelay, ScriptConfig, SubConfig},
     cypher_text::encode::Encode,
 };
 
 use super::{oracle_location::OracleLocation, Oracle};
 
-pub struct ScriptOracle {
+pub(crate) struct ScriptOracle {
     path: PathBuf,
     config: ScriptConfig,
 }
@@ -62,7 +62,7 @@ impl Oracle for ScriptOracle {
     fn location(&self) -> OracleLocation {
         OracleLocation::Script(self.path.clone())
     }
-    fn thread_delay(&self) -> u64 {
-        *self.config.thread_delay()
+    fn thread_delay(&self) -> &ThreadDelay {
+        self.config.thread_delay()
     }
 }
