@@ -6,7 +6,7 @@ use reqwest::{
 };
 
 use crate::{
-    config::{web_config::WebConfig, SubConfig},
+    config::{thread_delay::ThreadDelay, SubConfig, WebConfig},
     cypher_text::encode::Encode,
     oracle::oracle_location::OracleLocation,
 };
@@ -16,16 +16,19 @@ use super::{build_web_oracle, replace_keyword_occurrences, KeywordLocation};
 /// Unlike with `ScriptOracle`, we don't know which response from the web oracle corresponds with "valid", and which corresponds to "incorrect padding". For `WebOracle` to magically work, we need to determine the "incorrect padding" response. This struct manages the requests used for the calibration.
 /// `ask_validation` needs to return the web request's `Response`.Meaning, `Oracle` can't be implemented. Also, implementing it would be confusing as `CalibrateWebOracle`'s purpose is different from normal oracles.
 #[derive(Getters)]
-pub struct CalibrationWebOracle {
+pub(crate) struct CalibrationWebOracle {
     url: Url,
-    #[getset(get = "pub")]
+    #[getset(get = "pub(crate)")]
     config: WebConfig,
     web_client: Client,
     keyword_locations: Vec<KeywordLocation>,
 }
 
 impl CalibrationWebOracle {
-    pub fn visit(oracle_location: &OracleLocation, oracle_config: &SubConfig) -> Result<Self> {
+    pub(crate) fn visit(
+        oracle_location: &OracleLocation,
+        oracle_config: &SubConfig,
+    ) -> Result<Self> {
         let (url, web_client, keyword_locations, web_config) =
             build_web_oracle(oracle_location, oracle_config)?;
 
@@ -38,7 +41,7 @@ impl CalibrationWebOracle {
         Ok(oracle)
     }
 
-    pub fn ask_validation<'a>(&self, cypher_text: &'a impl Encode<'a>) -> Result<Response> {
+    pub(crate) fn ask_validation<'a>(&self, cypher_text: &'a impl Encode<'a>) -> Result<Response> {
         let (url, data, headers) = replace_keyword_occurrences(
             &self.url,
             &self.config,
@@ -61,7 +64,7 @@ impl CalibrationWebOracle {
         request.send().context("Sending request failed")
     }
 
-    pub fn thread_delay(&self) -> u64 {
-        *self.config.thread_delay()
+    pub(crate) fn thread_delay(&self) -> &ThreadDelay {
+        self.config.thread_delay()
     }
 }
